@@ -136,9 +136,9 @@ setMethod("show", "pICList", function(object){
 
     if(is(oI,"IC"))
        show(oI)
-    else{oIC <- object[[i]]@Curve
+    else{oIC <- oI@Curve
          for(j in 1:length(oIC))
              show(oIC[[j]]@Map)
     }
   }
-})
\ No newline at end of file
+})
