@@ -22,7 +22,7 @@ setMethod("confint", signature(object="ALEstimate", method="missing"),
 ### code borrowed from confint.default from package stats
     a <- (1 - level)/2
     a <- c(a, 1 - a)
-    pct <- stats:::format.perc(a, 3)
+    pct <- .format.perc(a, 3)
     fac <- qnorm(a)
     ci <- array(NA, dim = c(length(object@estimate), 2),
                 dimnames = list(names(object@estimate), pct))
@@ -58,7 +58,7 @@ setMethod("confint", signature(object="ALEstimate", method="symmetricBias"),
 ### code borrowed from confint.default from package stats
     a <- (1 - level)/2
     a <- c(a, 1 - a)
-    pct <- stats:::format.perc(a, 3)
+    pct <- .format.perc(a, 3)
     fac <- qnorm(a, mean = c(-object@asbias, object@asbias))
     ci <- array(NA, dim = c(length(object@estimate), 2),
                 dimnames = list(names(object@estimate), pct))
@@ -97,7 +97,7 @@ setMethod("confint", signature(object="ALEstimate", method="onesidedBias"),
 ### code borrowed from confint.default from package stats
     a <- (1 - level)/2
     a <- c(a, 1 - a)
-    pct <- stats:::format.perc(a, 3)
+    pct <- .format.perc(a, 3)
     if(method@sign == -1)
         M <- c(-object@asbias, 0)
     else
@@ -140,7 +140,7 @@ setMethod("confint", signature(object="ALEstimate", method="asymmetricBias"),
 ### code borrowed from confint.default from package stats
     a <- (1 - level)/2
     a <- c(a, 1 - a)
-    pct <- stats:::format.perc(a, 3)
+    pct <- .format.perc(a, 3)
     fac <- qnorm(a, mean = c(-object@asbias, object@asbias)/method@nu)
     ci <- array(NA, dim = c(length(object@estimate), 2),
                 dimnames = list(names(object@estimate), pct))
