@@ -5,13 +5,15 @@ setMethod("getBiasIC", signature(IC = "IC",
                                  neighbor = "UncondNeighborhood"),
     function(IC, neighbor, L2Fam, biastype = symmetricBias(),
              normtype = NormType(), tol = .Machine$double.eps^0.25,
-             numbeval = 1e5){
+             numbeval = 1e5, withCheck = TRUE){
 
         misF <- FALSE
         if(missing(L2Fam)){
             misF <- TRUE 
             L2Fam <- eval(IC@CallL2Fam)
         }
+        if(missing(withCheck)) withCheck <- TRUE
+
         D1 <- L2Fam@distribution
         if(dimension(Domain(IC@Curve[[1]])) != dimension(img(D1)))
             stop("dimension of 'Domain' of 'Curve' != dimension of 'img' of 'distribution' of 'L2Fam'")
@@ -22,12 +24,7 @@ setMethod("getBiasIC", signature(IC = "IC",
         Bias <- .evalBiasIC(IC = IC, neighbor = neighbor, biastype = biastype,
                             normtype = normtype, x = x, trafo = trafo(L2Fam@param))
 
-        prec <- if(misF) checkIC(IC, out = FALSE) else
-                         checkIC(IC, L2Fam, out = FALSE)
-        if(prec > tol)
-            warning("The maximum deviation from the exact IC properties is ", prec,
-                    "\nThis is larger than the specified 'tol' ",
-                    "=> the result may be wrong")
+        if(withCheck) if(misF) .checkICWithWarning(IC, tol=tol) else .checkICWithWarning(IC, L2Fam, tol=tol)
         return(list(asBias = list(distribution = .getDistr(L2Fam),
                     neighborhood = neighbor@type, value = Bias)))
     })
