@@ -23,6 +23,17 @@ setMethod("qqplot", signature(x = "ANY",
     n.adj = TRUE){
 
     mc <- match.call(call = sys.call(sys.parent(1)))
+    dots <- match.call(call = sys.call(sys.parent(1)),
+                       expand.dots = FALSE)$"..."
+    args0 <- list(x = x, y = y,
+                  n = if(!missing(n)) n else length(x),
+                  withIdLine = withIdLine, withConf = withConf,
+    withConf.pw  = if(!missing(withConf.pw)) withConf.pw else if(!missing(withConf)) withConf else NULL,
+    withConf.sim = if(!missing(withConf.sim)) withConf.sim else if(!missing(withConf)) withConf else NULL,
+                  plot.it = plot.it, xlab = xlab, ylab = ylab, distance=distance, n.adj=n.adj)
+
+    plotInfo <- list(call=mc, dots=dots, args=args0)
+
     xcc <- as.character(deparse(mc$x))
     if(missing(xlab)) mc$xlab <- xcc
     if(missing(ylab)) mc$ylab <- as.character(deparse(mc$y))
@@ -47,10 +58,14 @@ setMethod("qqplot", signature(x = "ANY",
 
     xD <- fct(distance)(x)
     x.cex <- 3/(1+log(1+xD))
-    mcl$cex.pch <- x.cex
+    mcl$cex.pts <- x.cex
 
-    return(invisible(do.call(getMethod("qqplot", signature(x="ANY", y="ProbFamily")),
-            args=mcl)))
+    retv <- do.call(getMethod("qqplot", signature(x="ANY", y="ProbFamily")),
+            args=mcl)
+    retv$call <- retv$dots <- retv$args <- NULL
+    plotInfo <- c(plotInfo,retv)
+    class(plotInfo) <- c("qqplotInfo","DiagnInfo")
+    return(invisible(plotInfo))
     })
 
 
@@ -62,6 +77,17 @@ setMethod("qqplot", signature(x = "ANY", y = "InfRobModel"),
                ylab = deparse(substitute(y)), ..., cex.pts.fun = NULL, n.adj = TRUE){
 
     mc <- match.call(call = sys.call(sys.parent(1)))
+    dots <- match.call(call = sys.call(sys.parent(1)),
+                       expand.dots = FALSE)$"..."
+    args0 <- list(x = x, y = y,
+                  n = if(!missing(n)) n else length(x),
+                  withIdLine = withIdLine, withConf = withConf,
+    withConf.pw  = if(!missing(withConf.pw)) withConf.pw else if(!missing(withConf)) withConf else NULL,
+    withConf.sim = if(!missing(withConf.sim)) withConf.sim else if(!missing(withConf)) withConf else NULL,
+                  plot.it = plot.it, xlab = xlab, ylab = ylab, cex.pts.fun=cex.pts.fun,
+                  n.adj = n.adj)
+
+    plotInfo <- list(call=mc, dots=dots, args=args0)
     if(missing(xlab)) mc$xlab <- as.character(deparse(mc$x))
     if(missing(ylab)) mc$ylab <- as.character(deparse(mc$y))
     mcl <- as.list(mc)[-1]
@@ -100,10 +126,14 @@ setMethod("qqplot", signature(x = "ANY", y = "InfRobModel"),
 
     x.cex <- 3/(1+.cexscale(xD,xD,cex=cex.pts, fun = cex.pts.fun))
 
-    mcl$cex.pch <- x.cex
+    mcl$cex.pts <- x.cex
 
-    return(invisible(do.call(getMethod("qqplot", signature(x="ANY", y="ProbFamily")),
-            args=mcl)))
+    retv <- do.call(getMethod("qqplot", signature(x="ANY", y="ProbFamily")),
+            args=mcl)
+    retv$call <- retv$dots <- retv$args <- NULL
+    plotInfo <- c(plotInfo,retv)
+    class(plotInfo) <- c("qqplotInfo","DiagnInfo")
+    return(invisible(plotInfo))
     })
 
 ## into RobAStBase
@@ -113,14 +143,25 @@ setMethod("qqplot", signature(x = "ANY",
     withConf.pw  = withConf,  withConf.sim = withConf,
     plot.it = TRUE, xlab = deparse(substitute(x)),
     ylab = deparse(substitute(y)), ...,
-    exp.cex2.lbl = -.15,
-    exp.cex2.pch = -.35,
-    exp.fadcol.lbl = 1.85,
-    exp.fadcol.pch = 1.85,
+    exp.cex2.lbs = -.15,
+    exp.cex2.pts = -.35,
+    exp.fadcol.lbs = 1.85,
+    exp.fadcol.pts = 1.85,
     bg = "white"
     ){
 
+    args0 <- list(x=x,y=y,n=n,withIdLine=withIdLine, withConf=withConf,
+        withConf.pw  = if(!missing(withConf.pw)) withConf.pw else if(!missing(withConf)) withConf else NULL,
+        withConf.sim = if(!missing(withConf.sim)) withConf.sim else if(!missing(withConf)) withConf else NULL,
+        plot.it = plot.it, xlab = xlab, ylab = ylab, exp.cex2.lbs=exp.cex2.lbs,
+        exp.cex2.pts=exp.cex2.pts, exp.fadcol.lbs=exp.fadcol.lbs,
+        exp.fadcol.pts=exp.fadcol.pts, bg=bg)
+
     mc <- match.call(call = sys.call(sys.parent(1)))
+    mc1 <- match.call(call = sys.call(sys.parent(1)), expand.dots=FALSE)
+    dots <- mc1$"..."
+    plotInfo <- list(call=mc, dots=dots, args=args0)
+
     if(missing(xlab)) mc$xlab <- as.character(deparse(mc$x))
     if(missing(ylab)) mc$ylab <- as.character(deparse(mc$y))
     mcl <- as.list(mc)[-1]
@@ -143,20 +184,25 @@ setMethod("qqplot", signature(x = "ANY",
       w.fct <- function(x)
                weight(weight(IC))(L.fct(matrix(x))[,,1])
 
-      wx <- w.fct(x)
+      wx <- 1/(1+w.fct(x))
+      if(max(wx)>1) wx <- wx/max(wx)
       mcl$order.traf <- function(x) 1/w.fct(x)
 
-      cex.lbl <- if(is.null(mcl$cex.lbl))  par("cex")  else eval(mcl$cex.lbl)
-      cex.pch <- if(is.null(mcl$cex.pch))  par("cex")  else eval(mcl$cex.pch)
-      mcl$cex.lbl <- cex.lbl*wx^exp.cex2.lbl
-      mcl$cex.pch <- cex.pch*wx^exp.cex2.pch
+      cex.lbs <- if(is.null(mcl$cex.lbs))  par("cex")  else eval(mcl$cex.lbs)
+      cex.pts <- if(is.null(mcl$cex.pts))  par("cex")  else eval(mcl$cex.pts)
+      mcl$cex.lbs <- cex.lbs*wx^exp.cex2.lbs
+      mcl$cex.pts <- cex.pts*wx^exp.cex2.pts
 
-      col.lbl <- if(is.null(mcl$col.lbl))  par("col")  else eval(mcl$col.lbl)
-      col.pch <- if(is.null(mcl$col.pch))  par("col")  else eval(mcl$col.pch)
-      mcl$col.lbl <- .fadeColor(col.lbl,wx^exp.fadcol.lbl, bg = bg)
-      mcl$col.pch <- .fadeColor(col.pch,wx^exp.fadcol.pch, bg = bg)
+      col.lbs <- if(is.null(mcl$col.lbs))  par("col")  else eval(mcl$col.lbs)
+      col.pts <- if(is.null(mcl$col.pts))  par("col")  else eval(mcl$col.pts)
+      mcl$col.lbs <- .fadeColor(col.lbs,wx^exp.fadcol.lbs, bg = bg)
+      mcl$col.pts <- .fadeColor(col.pts,wx^exp.fadcol.pts, bg = bg)
     }
 
-    return(invisible(do.call(getMethod("qqplot", signature(x="ANY", y="ProbFamily")),
-            args=mcl)))
+    retv <- do.call(getMethod("qqplot", signature(x="ANY", y="ProbFamily")),
+            args=mcl)
+    retv$call <- retv$dots <- retv$args <- NULL
+    plotInfo <- c(plotInfo,retv)
+    class(plotInfo) <- c("qqplotInfo","DiagnInfo")
+    return(invisible(plotInfo))
     })
